@@ -430,8 +430,7 @@ Logger <- R6::R6Class(
       start_format <- format(self$start_time, "%Y%m%d.%H%M")
       timestamp <- private$timestamp
 
-      if (is.character(timestamp)) timestamp <- as.Date(timestamp)
-      ts_format <- format(timestamp, "%Y_%m_%d")
+      ts_format <- format(db_timestamp(timestamp), "%Y_%m_%d")
       filename <- sprintf(
         "%s.%s.%s.log",
         start_format,
