@@ -24,7 +24,10 @@ digest_to_checksum <- function(.data, col = "checksum", exclude = NULL) {
   checkmate::assert_character(exclude, null.ok = TRUE)
 
   if (as.character(dplyr::ensym(col)) %in% colnames(.data)) {
-    warning(glue::glue("Column {as.character(dplyr::ensym(col))} already exists in data and will be overwritten!"))
+    warning(
+      glue::glue("Column {as.character(dplyr::ensym(col))} already exists in data and will be overwritten!"),
+      call. = FALSE
+    )
   }
 
   UseMethod("digest_to_checksum", .data)
@@ -72,12 +75,14 @@ digest_to_checksum.default <- function(
       id__ = dplyr::row_number(),
       dplyr::across(tidyselect::all_of(col), openssl::md5)
     ) %>%
-    dplyr::copy_to(dbplyr::remote_con(.data), df = ., name = unique_table_name())
+    dplyr::copy_to(dbplyr::remote_con(.data), df = ., name = unique_table_name("SCDB_digest_to_checksum_helper"))
+  defer_db_cleanup(checksums)
 
   .data <- .data %>%
     dplyr::mutate(id__ = dplyr::row_number()) %>%
-    dplyr::left_join(checksums, by = "id__", copy = TRUE) %>%
-    dplyr::select(!"id__")
+    dplyr::left_join(checksums, by = "id__") %>%
+    dplyr::select(!"id__") %>%
+    dplyr::compute(unique_table_name("SCDB_digest_to_checksum"))
 
   return(.data)
 }
